@@ -24,7 +24,7 @@
 #' @return A data frame (or tibble, if \code{tibble} is loaded)
 #' with column names `query-term` and `query-register`.
 #' The data frame (or tibble) can be passed as such as parameter
-#' `query-term` to \link{ctrLoadQueryIntoDb} and as parameter
+#' `queryterm` to \link{ctrLoadQueryIntoDb} and as parameter
 #' `url` to \link{ctrOpenSearchPagesInBrowser}.
 #'
 #' @importFrom clipr read_clip
@@ -198,8 +198,12 @@ ctrGetQueryUrl <- function(
 
     # sanity correction for naked terms
     queryterm <- sub(
-      "(^|&|[&]?\\w+=\\w+&)([ a-zA-Z0-9+-]+)($|&\\w+=\\w+)",
-      "\\1query=\\2\\3", queryterm
+      paste0(
+        "(^|&|[&]?\\w+=\\w+&)(",
+        gsub("[=&^]", "", regQueryterm),
+        "+)($|&\\w+=\\w+)"),
+      "\\1query=\\2\\3",
+      queryterm
     )
 
     # check if url was for results of single trial
